@@ -1,22 +1,23 @@
 #' Install a BEAST2 package
-#' @param name the package's name
+#'
+#' Install a BEAST2 package. If the package is already installed,
+#' (see \link{is_beast2_pkg_installed}), this function \link{stop}s.
+#' @inheritParams default_params_doc
 #' @return nothing. It does install the BEAST2 package
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#' library(testthat)
-#'
-#' # Only install a package on Travis,
-#' # if BEAST2 is installed and the package is not
-#' if (is_on_travis() &&
-#'   is_beast2_installed()
-#'   && !is_beast2_ns_pkg_installed()
-#' ) {
+#' \dontrun{
 #'   install_beast2_pkg("NS")
-#'   expect_true(is_beast2_ns_pkg_installed())
 #' }
 #' @export
 install_beast2_pkg <- function(name) {
-  if (is_beast2_pkg_installed(name)) {
+  if (!name %in% get_beast2_pkg_names()$name) {
+    stop(
+      "Invalid package name '", name, "'. \n",
+      "Tip: use 'get_beast2_pkg_names' to see all BEAST2 package names"
+    )
+  }
+  if (mauricer::is_beast2_pkg_installed(name)) {
     stop("Cannot install installed package")
   }
   # java -cp beast.jar beast.util.PackageManager -add bacter
