@@ -1,8 +1,10 @@
-#' Checks if a BEAST2 package is already installed.
+#' Is a BEAST2 package installed?
+#'
+#' Checks if a BEAST2 package is installed.
 #'
 #' To be able to check this, an internet connection is needed.
 #' Without an internet connection, \code{NULL} is returned.
-#' @param name BEAST2 package name
+#' @inheritParams default_params_doc
 #' @return
 #' \itemize{
 #'   \item \code{TRUE} if the BEAST2 package is installed
@@ -13,20 +15,16 @@
 #'   to see if the NS package is installed without an internet connection
 #' @author Richèl J.C. Bilderbeek
 #' @examples
-#' library(testthat)
-#'
-#' if (is_beast2_installed() && curl::has_internet()) {
-#'   print(
-#'     paste(
-#'       "Is the Beasy BEAST2 package installed:",
-#'       is_beast2_pkg_installed("Beasy")
-#'     )
-#'   )
+#' \dontrun{
+#'   is_beast2_pkg_installed("Beasy")
 #' }
 #' @export
-is_beast2_pkg_installed <- function(name) {
+is_beast2_pkg_installed <- function(
+  name,
+  has_internet = curl::has_internet()
+) {
   if (name == "NS") return(mauricer::is_beast2_ns_pkg_installed())
-  if (!curl::has_internet()) return(NULL)
+  if (!has_internet) return(NULL)
   df <- mauricer::get_beast2_pkg_names()
   df[df$name == name, ]$installed_version != "NA"
 }
